kernel_switch_out_user_fpu

Function kernel_switch_out_user_fpu 

pub fn kernel_switch_out_user_fpu(vcpu: &mut Vcpu)
Save user FPU context when switching away from a task in the kernel.

RISC-V uses FS dirty tracking, so we only save when needed.