pub fn kernel_switch_out_user_vector(
cpu_id: usize,
task_id: usize,
vcpu: &mut Vcpu,
)Expand description
Handle user vector state on kernel switch-out.
We avoid saving vregs on every timeslice. If VS is dirty for the current owner, we mark the per-hart owner as dirty so the save can be deferred until another task must overwrite the live vregs.